Struct clockwork_sdk::state::AccountMetaData
source · Expand description
Account metadata needed to execute an instruction on Solana.
Fields
pubkey: PubkeyAn account’s public key
is_signer: boolTrue if an Instruction requires a Transaction signature matching pubkey.
is_writable: boolTrue if the pubkey can be loaded as a read-write account.
Implementations
sourceimpl AccountMetaData
impl AccountMetaData
sourcepub fn new(pubkey: Pubkey, is_signer: bool) -> AccountMetaData
pub fn new(pubkey: Pubkey, is_signer: bool) -> AccountMetaData
Construct metadata for a writable account.
sourcepub fn new_readonly(pubkey: Pubkey, is_signer: bool) -> AccountMetaData
pub fn new_readonly(pubkey: Pubkey, is_signer: bool) -> AccountMetaData
Construct metadata for a read-only account.