Struct clockwork_sdk::state::InstructionData
source · pub struct InstructionData {
pub program_id: Pubkey,
pub accounts: Vec<AccountMetaData, Global>,
pub data: Vec<u8, Global>,
}Expand description
The data needed execute an instruction on Solana.
Fields
program_id: PubkeyPubkey of the instruction processor that executes this instruction
accounts: Vec<AccountMetaData, Global>Metadata for what accounts should be passed to the instruction processor
data: Vec<u8, Global>Opaque data passed to the instruction processor