Struct clockwork_sdk::state::ThreadResponse
source · pub struct ThreadResponse {
pub kickoff_instruction: Option<InstructionData>,
pub next_instruction: Option<InstructionData>,
}Expand description
A response value target programs can return to update the thread.
Fields
kickoff_instruction: Option<InstructionData>The kickoff instruction to use on the next triggering of the thread. If none, the kickoff instruction remains unchanged.
next_instruction: Option<InstructionData>The next instruction to use on the next execution of the thread.