Struct clockwork_sdk::state::ThreadSettings
source · pub struct ThreadSettings {
pub fee: Option<u64>,
pub kickoff_instruction: Option<InstructionData>,
pub rate_limit: Option<u64>,
pub trigger: Option<Trigger>,
}Expand description
The properties of threads which are updatable.
Fields
fee: Option<u64>kickoff_instruction: Option<InstructionData>rate_limit: Option<u64>trigger: Option<Trigger>Trait Implementations
sourceimpl BorshDeserialize for ThreadSettingswhere
Option<u64>: BorshDeserialize,
Option<InstructionData>: BorshDeserialize,
Option<Trigger>: BorshDeserialize,
impl BorshDeserialize for ThreadSettingswhere
Option<u64>: BorshDeserialize,
Option<InstructionData>: BorshDeserialize,
Option<Trigger>: BorshDeserialize,
sourcefn deserialize(buf: &mut &[u8]) -> Result<ThreadSettings, Error>
fn deserialize(buf: &mut &[u8]) -> Result<ThreadSettings, Error>
Deserializes this instance from a given slice of bytes.
Updates the buffer to point at the remaining bytes.
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
fn try_from_slice(v: &[u8]) -> Result<Self, Error>
Deserialize this instance from a slice of bytes.